aboutsummaryrefslogtreecommitdiff
path: root/src/backend/utils/adt/enum.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/backend/utils/adt/enum.c')
-rw-r--r--src/backend/utils/adt/enum.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/backend/utils/adt/enum.c b/src/backend/utils/adt/enum.c
index 79117c4c904..0d892132a84 100644
--- a/src/backend/utils/adt/enum.c
+++ b/src/backend/utils/adt/enum.c
@@ -82,12 +82,12 @@ check_safe_enum_use(HeapTuple enumval_tup)
return;
/*
* Check if the enum value is blacklisted. If not, it's safe, because it
* was made during CREATE TYPE AS ENUM and can't be shorter-lived than its
* owning type. (This'd also be false for values made by other
* transactions; but the previous tests should have handled all of those.)
*/
- if (!EnumBlacklisted(en->oid))
+ if (!EnumUncommitted(en->oid))
return;
/*
@@ -82,12 +82,12 @@ check_safe_enum_use(HeapTuple enumval_tup)
return;
/*
- * Check if the enum value is blacklisted. If not, it's safe, because it
+ * Check if the enum value is uncommitted. If not, it's safe, because it
* was made during CREATE TYPE AS ENUM and can't be shorter-lived than its
* owning type. (This'd also be false for values made by other